

#    MIDAS Access Client  for the  VHSADC service

package require MIDASAccessClient    ;#   load default support procedures

global MIDAS_VHSADCAccessClient_Exists
set MIDAS_VHSADCAccessClient_Exists 1

global VHSADCAccessServerHost VHSADCAccessServerPort

if {![info exists VHSADCAccessServerHost]} then {set VHSADCAccessServerHost localhost}
if {![info exists VHSADCAccessServerPort]} then {set VHSADCAccessServerPort 8015}

variable uri "urn:VHSADCAccessServer"
variable proxy "http://$VHSADCAccessServerHost:$VHSADCAccessServerPort/VHSADCAccessServer"

set VHSADCAccessServerTimeOut 10000

proc VHSADCAccessClient_Configure {} {
   global VHSADCAccessServerHost VHSADCAccessServerPort
   variable proxy

   set proxy "http://$VHSADCAccessServerHost:$VHSADCAccessServerPort/VHSADCAccessServer"

   foreach method [info procs VHSADCAccessClient__*] {catch {SOAP::configure $method -proxy $proxy}}
}


proc VHSADCAccessClient_SetUpTemp {} {
   global env 

   if {![info exists env(MIDASTempDir)] || ![file exists $env(MIDASTempDir)]} then {
       switch $env(os) {
          Win {set env(MIDASTempDir) [file join c:/ temp]}
          default {set env(MIDASTempDir) /tmp}
       }
   }

   catch {file mkdir $env(MIDASTempDir}
   catch {file mkdir [file join $env(MIDASTempDir) VHSADCAccessClient]}
}

proc VHSADCAccessClient_VHSADCUpLoad {file} {
    global env

    VHSADCAccessClient_SetUpTemp

    set path [file join $env(MIDASTempDir) VHSADCAccessClient [file tail $file].base64]

# different implementations of this command take different arguments!
    set z [catch {exec base64 $file > $path} m]
    if {$z != 0} then {InsertLog "Error in base64 encoding $file in VHSADCUpLoad\n$m\nTrying a different variant of the command"}
    if {$z != 0} then {set z [catch {exec base64 --encode $file $path} m]}
    if {$z != 0} then {InsertLog "Error in base64 encoding $file in VHSADCUpLoad\n$m\nTrying another different variant of the command"}
    if {$z != 0} then {set z [catch {exec base64 -e $file $path} m]}
    if {$z != 0} then {InsertLog "Error in base64 encoding $file in VHSADCUpLoad\n$m"; return}

    set z [catch {open $path r} f]
    if {$z != 0} then {InsertLog "Cannot open file $path\n$f"; return}
    set contents [read $f]
    close $f

    VHSADCAccessClient__VHSADCUpLoad $file $contents
}


SOAP::create VHSADCAccessClient__VHSADCInit -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
     -name VHSADCInit \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply 

SOAP::create VHSADCAccessClient__VHSADCUpLoad -proxy $proxy -uri $uri -timeout [expr 2*$VHSADCAccessServerTimeOut] \
     -name VHSADCUpLoad \
     -params {file string contents string}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__Vhsadac16FpgaReset -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
     -name Vhsadac16FpgaReset \
     -params {id int bitstream string int len}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__Vhsadac16FpgaLoad -proxy $proxy -uri $uri -timeout [expr 4*$VHSADCAccessServerTimeOut] \
     -name Vhsadac16FpgaLoad \
     -params {id int bitstream string}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__Vhsadac16FlashProgram -proxy $proxy -uri $uri -timeout [expr 20*$VHSADCAccessServerTimeOut] \
     -name Vhsadac16FlashProgram \
     -params {id int bitstream string}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__Vhsadac16FlashErase -proxy $proxy -uri $uri -timeout [expr 4*$VHSADCAccessServerTimeOut] \
     -name Vhsadac16FlashErase \
     -params {id int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__Vhsadac16FlashBoot -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
     -name Vhsadac16FlashBoot \
     -params {id int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__Vhsadac16ReadFpgaReg -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
     -name Vhsadac16ReadFpgaReg \
     -params {id int register int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__Vhsadac16ReadFpgaRegs -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
     -name Vhsadac16ReadFpgaRegs \
     -params {id int registers int()}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__ReadUserRegs -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
     -name VHSADCReadUserRegs \
     -params {id int registers int()}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__Vhsadac16WriteFpgaReg -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
     -name Vhsadac16WriteFpgaReg \
     -params {id int register int value int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

package require rpcvar
namespace import -force rpcvar::typedef

typedef {
   register int
   value int
} itemStruct

SOAP::create VHSADCAccessClient__Vhsadac16WriteFpgaRegs -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
     -name Vhsadac16WriteFpgaRegs \
     -params {id int registers itemStruct()}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__WriteUserRegs -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
     -name VHSADCWriteUserRegs \
     -params {id int registers int()}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__Vhsadac16GetCpldRegs -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
     -name Vhsadac16GetCpldRegs \
     -params {id int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

#    following is for Virtex2
# SOAP::create VHSADCAccessClient__Vhsadac16Clock_Frequency -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
#     -name Vhsadac16Clock_Frequency \
#     -params {id int freq int}  \
#     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
#     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__VHSADCExit -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
     -name VHSADCExit \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCAccessClient__VHSADCVerbose -proxy $proxy -uri $uri -timeout $VHSADCAccessServerTimeOut \
     -name VHSADCVerbose \
     -params {opt int} \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply 



package provide VHSADCAccessClient 1.0

